@@ -6,6 +6,10 @@ Q_FOR_STMT = """
 (for_statement) @stmt
 """
 
+Q_FOR_RANGE_STMT = """
+(for_range_loop) @stmt
+"""
+
 Q_DO_STMT = """
 (do_statement) @stmt
 """
@@ -15,14 +19,13 @@ Q_WHILE_STMT = """
 """
 
 Q_IF_STMT = """
-(if_statement) @if_stmt
+(if_statement) @stmt
 """
 
 Q_SWITCH_STMT = """
 (switch_statement) @stmt
 """
 
-
 Q_CONDITION = """
 (_
     condition: ((_) @condition)
@@ -33,6 +36,18 @@ Q_BINARY_EXPR = """
 (binary_expression) @expr
 """
 
+Q_UPDATE_EXPR = """
+(update_expression) @expr
+"""
+
+Q_SUBSCRIPT_EXPR = """
+(subscript_expression) @expr
+"""
+
+Q_FIELD_EXPR = """
+(field_expression) @expr
+"""
+
 Q_CALL_NAME = """
 (call_expression
     function: ((identifier) @name)
@@ -49,7 +64,19 @@ Q_IDENTIFIER = """
 (identifier) @variable
 """
 
-Q_FUNCTION_PARAMETER = """
+Q_NUMBER = """
+(number_literal) @constant
+"""
+
+#Q_FUNCTION_PARAMETER = """
+#(parameter_declaration) @param
+#"""
+
+Q_FUNCTION = """
+(function_definition) @function
+"""
+
+Q_PARAMETER = """
 (parameter_declaration) @param
 """
 
@@ -57,6 +84,11 @@ Q_POINTER_EXPR = """
 (pointer_expression) @pointer
 """
 
+Q_POINTER_IDENTIFIER = """
+(pointer_declarator
+    (identifier) @identifier)
+"""
+
 Q_ASSIGNMENT_EXPR = """
 (assignment_expression) @expr
 """
@@ -67,4 +99,8 @@ Q_IF_WITHOUT_ELSE = """
     consequence: ((_) @then)
     !alternative
 ) @stmt
-"""
\ No newline at end of file
+"""
+
+Q_NEW_EXPRESSION = """
+(new_expression) @expr
+"""
